==> evadb-0.2.7.tar.gz: evadb-0.2.7/evadb/models/server/response.py <==
# coding=utf-8
# Copyright 2018-2023 EVA
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from dataclasses import dataclass
from enum import Enum
from typing import Optional

from evadb.executor.executor_utils import ExecutorError
from evadb.models.storage.batch import Batch
from evadb.utils.generic_utils import PickleSerializer


class ResponseStatus(str, Enum):
    FAIL = -1
    SUCCESS = 0


@dataclass(frozen=True)
class Response:
    """
    Data model for EVA server response
    """

    status: ResponseStatus = ResponseStatus.FAIL
    batch: Batch = None
    error: Optional[str] = None
    query_time: Optional[float] = None

    def serialize(self):
        return PickleSerializer.serialize(self)

    @classmethod
    def deserialize(cls, data):
        obj = PickleSerializer.deserialize(data)
        return obj

    def as_df(self):
        if self.error is not None:
            raise ExecutorError(self.error)
        if self.batch is None:
            raise ExecutorError("Empty batch")
        return self.batch.frames

    def __str__(self):
        if self.query_time is not None:
            return (
                "@status: %s\n"
                "@batch: \n %s\n"
                "@query_time: %s" % (self.status, self.batch, self.query_time)
            )
        else:
            return (
                "@status: %s\n"
                "@batch: \n %s\n"
                "@error: %s" % (self.status, self.batch, self.error)
            )

==> evadb-0.2.11.tar.gz: evadb-0.2.11/evadb/models/server/response.py <==
# coding=utf-8
# Copyright 2018-2023 EvaDB
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from dataclasses import dataclass
from enum import Enum
from typing import Optional

from evadb.executor.executor_utils import ExecutorError
from evadb.models.storage.batch import Batch
from evadb.utils.generic_utils import PickleSerializer


class ResponseStatus(str, Enum):
    FAIL = -1
    SUCCESS = 0


@dataclass(frozen=True)
class Response:
    """
    Data model for EvaDB server response
    """

    status: ResponseStatus = ResponseStatus.FAIL
    batch: Batch = None
    error: Optional[str] = None
    query_time: Optional[float] = None

    def serialize(self):
        return PickleSerializer.serialize(self)

    @classmethod
    def deserialize(cls, data):
        obj = PickleSerializer.deserialize(data)
        return obj

    def as_df(self):
        if self.error is not None:
            raise ExecutorError(self.error)
        if self.batch is None:
            raise ExecutorError("Empty batch")
        return self.batch.frames

    def __str__(self):
        if self.query_time is not None:
            return (
                "@status: %s\n"
                "@batch: \n %s\n"
                "@query_time: %s" % (self.status, self.batch, self.query_time)
            )
        else:
            return (
                "@status: %s\n"
                "@batch: \n %s\n"
                "@error: %s" % (self.status, self.batch, self.error)
            )
